@@ -367,7 +367,11 @@ class ProductDetailsResponse(object):
             parsed_json.get("quantity_unit_stock")
         )
 
-        self._location = LocationData(parsed_json.get("location"))
+        raw_location = parsed_json.get("location")
+        if raw_location is None:
+            self._location = None
+        else:
+            self._location = LocationData(raw_location)
 
     @property
     def last_purchased(self) -> datetime:
@@ -485,7 +489,7 @@ class GrocyApiClient(object):
     def _do_post_request(self, end_url: str, data: dict):
         req_url = urljoin(self._base_url, end_url)
         resp = requests.post(
-            req_url, verify=self._verify_ssl, headers=self._headers, data=data
+            req_url, verify=self._verify_ssl, headers=self._headers, json=data
         )
         resp.raise_for_status()
         if len(resp.content) > 0:
